@@ -1,5 +1,36 @@
 import logging
 
+from smile_datasets import (
+    DatapipeForHardNegativeSimCSE,
+    DatapipeForMaksedLanguageModel,
+    DatapipeForQuestionAnswering,
+    DatapipeForSequenceClassifiation,
+    DatapipeForSupervisedSimCSE,
+    DatapipeForTokenClassification,
+    DatapipeForUnsupervisedSimCSE,
+    DatasetForHardNegativeSimCSE,
+    DatasetForMaskedLanguageModel,
+    DatasetForQuestionAnswering,
+    DatasetForSequenceClassification,
+    DatasetForSupervisedSimCSE,
+    DatasetForTokenClassification,
+    DatasetForUnsupervisedSimCSE,
+    ExampleForHardNegativeSimCSE,
+    ExampleForMaskedLanguageModel,
+    ExampleForQuestionAnswering,
+    ExampleForSequenceClassification,
+    ExampleForSupervisedSimCSE,
+    ExampleForTokenClassification,
+    ExampleForUnsupervisedSimCSE,
+    ParserForHardNegSimCSE,
+    ParserForMaskedLanguageModel,
+    ParserForQuestionAnswering,
+    ParserForSequenceClassification,
+    ParserForSupervisedSimCSE,
+    ParserForTokenClassification,
+    ParserForUnsupervisedSimCSE,
+)
+
 from transformers_keras.adapters.abstract_adapter import (
     AbstractAdapter,
     AbstractAlbertAdapter,
@@ -10,36 +41,7 @@ from transformers_keras.adapters.adapter_factory import AlbertAdapterFactory, Be
 from transformers_keras.adapters.albert_adapter import AlbertAdapter, AlbertAdapterForTensorFlow
 from transformers_keras.adapters.bert_adapter import BertAdapter, BertAdapterForTensorFlow
 from transformers_keras.adapters.mengzi_adapter import BertAdapterForLangboatMengzi
-from transformers_keras.common.char_tokenizer import BertCharTokenizer, TokenizerEncoding
-from transformers_keras.common.label_tokenizer import LabelTokenizerForTokenClassification
 from transformers_keras.common.metrics import ExactMatch, F1ForSequence
-from transformers_keras.datapipe.abc_dataset import AbstractDataset
-from transformers_keras.datapipe.mlm_dataset import (
-    DatasetForMaskedLanguageModel,
-    ExampleForMaskedLanguageModel,
-    WholeWordMask,
-)
-from transformers_keras.datapipe.qa_dataset import (
-    DatasetForQuestionAnswering,
-    DatasetForQuestionAnsweringX,
-    ExampleForQuestionAnswering,
-    ExampleForQuestionAnsweringX,
-)
-from transformers_keras.datapipe.sa_dataset import (
-    DatasetForAspectTermExtraction,
-    DatasetForOpinionTermExtractionAndClassification,
-    ExampleForAspectTermExtraction,
-)
-from transformers_keras.datapipe.sc_dataset import DatasetForSequenceClassification, ExampleForSequenceClassification
-from transformers_keras.datapipe.se_dataset import (
-    DatasetForHardNegativeSimCSE,
-    DatasetForSupervisedSimCSE,
-    DatasetForUnsupervisedSimCSE,
-    ExampleForHardNegativeSimCSE,
-    ExampleForSupervisedSimCSE,
-    ExampleForUnsupervisedSimCSE,
-)
-from transformers_keras.datapipe.tc_dataset import DatasetForTokenClassification, ExampleForTokenClassification
 from transformers_keras.distiller import Distiller
 from transformers_keras.lm.mlm import BertForMaskedLanguageModel
 from transformers_keras.modeling_albert import (
@@ -90,6 +92,6 @@ from transformers_keras.token_classification.crf_models import (
 from transformers_keras.token_classification.models import AlbertForTokenClassification, BertForTokenClassification
 
 __name__ = "transformers_keras"
-__version__ = "0.4.9"
+__version__ = "0.5.0"
 
 logging.basicConfig(format="%(asctime)s %(levelname)7s %(filename)20s %(lineno)4d] %(message)s", level=logging.INFO)
